declare const LightPen_base: {
    new (...args: any[]): {
        [x: string]: any;
    };
    baseName: string;
    warnOnExistingElement: boolean;
    define(name?: string | null | undefined, ctor?: CustomElementConstructor | null | undefined, options?: ElementDefinitionOptions | undefined): void;
} & typeof LitElement;
/**
 * @typedef {"html" | "css" | "js"} SupportedLanguages
 * @typedef {HTMLTextAreaElement | HTMLScriptElement | HTMLTemplateElement} SafeTemplateElements
 */
/**
 * @customElement
 * @tagName lit-pen
 * @slot html - HTML to insert
 * @slot css - CSS to insert
 * @slot js - JavaScript to insert
 * @slot title - The title to appear at the top of the editor
 *
 */
export default class LightPen extends LightPen_base {
    static styles: import("lit").CSSResult[];
    static languageMap: {
        html: string;
        css: string;
        js: string;
    };
    static properties: {
        openLanguages: {
            reflect: boolean;
            attribute: string;
        };
        resizePosition: {
            attribute: string;
            reflect: boolean;
            type: NumberConstructor;
        };
        console: {
            reflect: boolean;
        };
        languages: {
            state: boolean;
            type: ArrayConstructor;
        };
        cssCode: {
            state: boolean;
        };
        htmlCode: {
            state: boolean;
        };
        jsCode: {
            state: boolean;
        };
    };
    /**
     * @prop
     * @type {ResizeObserver}
     */
    resizeObserver: ResizeObserver;
    /**
     *
     */
    /**
     * @attr
     * @reflect
     * @type {number}
     */
    resizePosition: number;
    /**
     * Languages to have open on initial render
     * Comma separated list of elements to open on initial render "html,css,js" to open all.
     * @reflect
     * @type {string}
     */
    openLanguages: string;
    /**
     * @type {Array<SupportedLanguages>}
     */
    languages: Array<SupportedLanguages>;
    /**
     * @reflect
     * @type {"console" | "iframe"}
     */
    result: string;
    /**
     * @property
     * @type {"enabled" | "disabled"}
     */
    console: string;
    /**
     * @property
     * @type {string}
     */
    consoleText: string;
    /**
     * @property
     * @type {string}
     */
    htmlReset: string;
    /**
     * @property
     * @type {string}
     */
    cssReset: string;
    /**
     * @property
     * @type {string}
     */
    jsReset: string;
    /**
     * @property
     * @type {number}
     */
    cachedWidth: number;
    /**
     * Sets an initial width so we dont need to keep computing getBoundingClientRect
     */
    updateCachedWidth(): void;
    /**
     * @param {ResizeObserverEntry[]} entries
     */
    handleResize(entries: ResizeObserverEntry[]): void;
    /** Getters / Setters */
    /**
     * @returns {null | undefined | HTMLIFrameElement}
     */
    get iframeElem(): HTMLIFrameElement | null | undefined;
    /**
     * Override this to use a highlighter of your choice.
     * @param {{code: string, language: SupportedLanguages}} options
     */
    highlightCode({ code, language }: {
        code: string;
        language: SupportedLanguages;
    }): string;
    /**
     * @param {string} text
     */
    escapeCharacters(text: string): string;
    /**
     * Highlighters strip newlines. But you can see new lines in <textarea>, this fixes that.
     * @param {string} text
     */
    injectNewLine(text: string): string;
    updateIframeContent(): void;
    inputHandler(): void;
    _iframeDebounce: number | undefined;
    /**
     * @param {HTMLTextAreaElement} textarea
     */
    htmlTextAreaChanged(textarea: HTMLTextAreaElement): void;
    htmlTextArea: HTMLTextAreaElement | undefined;
    /**
     * @param {HTMLTextAreaElement} textarea
     */
    cssTextAreaChanged(textarea: HTMLTextAreaElement): void;
    cssTextArea: HTMLTextAreaElement | undefined;
    /**
     * @param {HTMLTextAreaElement} textarea
     */
    jsTextAreaChanged(textarea: HTMLTextAreaElement): void;
    jsTextArea: HTMLTextAreaElement | undefined;
    /**
     * @param {KeyboardEvent} event
     */
    handleResizerKeydown(event: KeyboardEvent): void;
    updateResizePosition(resizePosition?: number): void;
    /**
     * Lovely helper to scoop up our html, css, and js code
     */
    updateCode(): void;
    cssCode: string | undefined;
    htmlCode: string | undefined;
    jsCode: string | undefined;
    resetValues(): void;
    /**
     * @param {KeyboardEvent} evt
     */
    keydownHandler(evt: KeyboardEvent): void;
    /**
     * @param {Event} e
     */
    handleTemplate(e: Event): void;
    renderConsole(): import("lit").TemplateResult<1>;
    /**
     * @override
     */
    override render(): import("lit").TemplateResult<1>;
    /**
     * @param {PointerEvent} event
     */
    handleDrag(event: PointerEvent): void;
    /**
     * @param {number} pixels
     * @return {number}
     */
    pixelsToPercentage(pixels: number): number;
    /**
     * @param {SupportedLanguages} language
     */
    renderDetails(language: SupportedLanguages): import("lit").TemplateResult<1>;
    /**
     * @internal
     * @param {Event} e
     */
    syncScroll(e: Event): void;
}
export type DragOptions = {
    /**
     * - Callback that runs as dragging occurs.
     */
    onMove: (x: number, y: number) => void;
    /**
     * - Callback that runs when dragging stops.
     */
    onStop: () => void;
    /**
     * - When an initial event is passed, the first drag will be triggered immediately using the coordinates therein. This is useful when the drag is initiated by a mousedown/touchstart event but you want the initial "click" to activate a drag (e.g. resizePositioning a handle initially at the click target).
     */
    initialEvent: PointerEvent;
};
export type SupportedLanguages = "html" | "css" | "js";
export type SafeTemplateElements = HTMLTextAreaElement | HTMLScriptElement | HTMLTemplateElement;
import { LitElement } from "lit";
export {};
